#
# Copyright (c) 2016 Nordic Semiconductor ASA
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#   1. Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
#   2. Redistributions in binary form must reproduce the above copyright notice, this
#   list of conditions and the following disclaimer in the documentation and/or
#   other materials provided with the distribution.
#
#   3. Neither the name of Nordic Semiconductor ASA nor the names of other
#   contributors to this software may be used to endorse or promote products
#   derived from this software without specific prior written permission.
#
#   4. This software must only be used in or with a processor manufactured by Nordic
#   Semiconductor ASA, or in or with a processor manufactured by a third party that
#   is used in combination with a processor manufactured by Nordic Semiconductor.
#
#   5. Any software provided in binary or object form under this license must not be
#   reverse engineered, decompiled, modified and/or disassembled.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# Python standard library
import os
import shutil
import logging
import tempfile
import struct
import binascii

# 3rd party libraries
import intelhex

# Nordic libraries
from nordicsemi.dfu.nrfhex import nRFArch
from nordicsemi.dfu.package import Package
from pc_ble_driver_py.exceptions import NordicSemiException

logger = logging.getLogger(__name__)

class BLDFUSettingsStructV1:

    def __init__(self, settings_address):
        self.bytes_count = 92
        self.crc               = settings_address + 0x0
        self.sett_ver          = settings_address + 0x4
        self.app_ver           = settings_address + 0x8
        self.bl_ver            = settings_address + 0xC
        self.bank_layout       = settings_address + 0x10
        self.bank_current      = settings_address + 0x14
        self.bank0_img_sz      = settings_address + 0x18
        self.bank0_img_crc     = settings_address + 0x1C
        self.bank0_bank_code   = settings_address + 0x20
        self.sd_sz             = settings_address + 0x34

        self.init_cmd          = settings_address + 0x5C
        self.last_addr         = settings_address + 0x5C


class BLDFUSettingsStructV2:

    def __init__(self, settings_address):
        self.bytes_count = 803 # Entire settings page
        self.crc                  = settings_address + 0x0
        self.sett_ver             = settings_address + 0x4
        self.app_ver              = settings_address + 0x8
        self.bl_ver               = settings_address + 0xC
        self.bank_layout          = settings_address + 0x10
        self.bank_current         = settings_address + 0x14
        self.bank0_img_sz         = settings_address + 0x18
        self.bank0_img_crc        = settings_address + 0x1C
        self.bank0_bank_code      = settings_address + 0x20
        self.sd_sz                = settings_address + 0x34
        self.init_cmd             = settings_address + 0x5C

        self.boot_validataion_crc = settings_address + 0x25C
        self.sd_validation_type   = settings_address + 0x260
        self.sd_validation_bytes  = settings_address + 0x261
        self.app_validation_type  = settings_address + 0x2A1
        self.app_validation_bytes = settings_address + 0x2A2

        self.last_addr            = settings_address + 0x322


class BLDFUSettings:
    """ Class to abstract a bootloader and its settings """

    flash_page_51_sz      = 0x400
    flash_page_52_sz      = 0x1000
    bl_sett_51_addr       = 0x0003FC00
    bl_sett_52_addr       = 0x0007F000
    bl_sett_52_qfab_addr  = 0x0003F000
    bl_sett_52810_addr    = 0x0002F000
    bl_sett_52840_addr    = 0x000FF000
    bl_sett_backup_offset = 0x1000

    def __init__(self):
        """
        """
        # instantiate a hex object
        self.ihex = intelhex.IntelHex()
        self.temp_dir = None
        self.hex_file = ""

    def __del__(self):
        """
        Destructor removes the temporary directory
        :return:
        """
        if self.temp_dir is not None:
            shutil.rmtree(self.temp_dir)

    def set_arch(self, arch):
        if arch == 'NRF51':
            self.arch = nRFArch.NRF51
            self.arch_str = 'nRF51'
            self.flash_page_sz = BLDFUSettings.flash_page_51_sz
            self.bl_sett_addr = BLDFUSettings.bl_sett_51_addr
        elif arch == 'NRF52':
            self.arch = nRFArch.NRF52
            self.arch_str = 'nRF52'
            self.flash_page_sz = BLDFUSettings.flash_page_52_sz
            self.bl_sett_addr = BLDFUSettings.bl_sett_52_addr
        elif arch == 'NRF52QFAB':
            self.arch = nRFArch.NRF52
            self.arch_str = 'nRF52QFAB'
            self.flash_page_sz = BLDFUSettings.flash_page_52_sz
            self.bl_sett_addr = BLDFUSettings.bl_sett_52_qfab_addr
        elif arch == 'NRF52810':
            self.arch = nRFArch.NRF52
            self.arch_str = 'NRF52810'
            self.flash_page_sz = BLDFUSettings.flash_page_52_sz
            self.bl_sett_addr = BLDFUSettings.bl_sett_52810_addr
        elif arch == 'NRF52840':
            self.arch = nRFArch.NRF52840
            self.arch_str = 'NRF52840'
            self.flash_page_sz = BLDFUSettings.flash_page_52_sz
            self.bl_sett_addr = BLDFUSettings.bl_sett_52840_addr
        else:
            raise RuntimeError("Unknown architecture")

    def _add_value_tohex(self, addr, value, format='<I'):
        self.ihex.puts(addr, struct.pack(format, value))

    def _get_value_fromhex(self, addr, size=4, format='<I'):
        return struct.unpack(format, self.ihex.gets(addr, size))[0] & 0xffffffff

    def _calculate_crc32_from_hex(self, ih_object, start_addr=None, end_addr=None):
        list = []
        if start_addr is None and end_addr is None:
            hex_dict = ih_object.todict()
            for addr, byte in list(hex_dict.items()):
                list.append(byte)
        else:
            for addr in range(start_addr, end_addr + 1):
                list.append(ih_object[addr])

        return binascii.crc32(bytearray(list)) & 0xFFFFFFFF

    def generate(self, arch, app_file, app_ver, bl_ver, bl_sett_ver, custom_bl_sett_addr, no_backup,
                 backup_address, app_boot_validation_type, sd_boot_validation_type, sd_file, signer):

        self.set_arch(arch)

        if custom_bl_sett_addr is not None:
            self.bl_sett_addr = custom_bl_sett_addr

        if bl_sett_ver == 1:
            self.setts = BLDFUSettingsStructV1(self.bl_sett_addr)
        elif bl_sett_ver == 2:
            self.setts = BLDFUSettingsStructV2(self.bl_sett_addr)
        else:
            raise NordicSemiException("Unknown bootloader settings version")

        self.bl_sett_ver = bl_sett_ver & 0xffffffff
        self.bl_ver = bl_ver & 0xffffffff

        if app_ver is not None:
            self.app_ver = app_ver & 0xffffffff
        else:
            self.app_ver = 0x0 & 0xffffffff

        if app_file is not None:
            # load application to find out size and CRC
            self.temp_dir = tempfile.mkdtemp(prefix="nrf_dfu_bl_sett_")
            self.app_bin = Package.normalize_firmware_to_bin(self.temp_dir, app_file)

            # calculate application size and CRC32
            self.app_sz = int(Package.calculate_file_size(self.app_bin)) & 0xffffffff
            self.app_crc = int(Package.calculate_crc(32, self.app_bin)) & 0xffffffff
            self.bank0_bank_code = 0x1 & 0xffffffff

            # Calculate Boot validation fields for app
            if app_boot_validation_type == 'VALIDATE_GENERATED_CRC':
                self.app_boot_validation_type = 1 & 0xffffffff
                self.app_boot_validation_bytes = struct.pack('<I', self.app_crc)
            elif app_boot_validation_type == 'VALIDATE_GENERATED_SHA256':
                self.app_boot_validation_type = 2 & 0xffffffff
                # Package.calculate_sha256_hash gives a reversed
                # digest. It need to be reversed back to a normal
                # sha256 digest.
                self.app_boot_validation_bytes = Package.calculate_sha256_hash(self.app_bin)[::-1]
            elif app_boot_validation_type == 'VALIDATE_ECDSA_P256_SHA256':
                self.app_boot_validation_type = 3 & 0xffffffff
                self.app_boot_validation_bytes = Package.sign_firmware(signer, self.app_bin)
            else:  # This also covers 'NO_VALIDATION' case
                self.app_boot_validation_type = 0 & 0xffffffff
                self.app_boot_validation_bytes = bytes(0)
        else:
            self.app_sz = 0x0 & 0xffffffff
            self.app_crc = 0x0 & 0xffffffff
            self.bank0_bank_code = 0x0 & 0xffffffff
            self.app_boot_validation_type = 0x0 & 0xffffffff
            self.app_boot_validation_bytes = bytes(0)

        if sd_file is not None:
            # Load SD to calculate CRC
            self.temp_dir = tempfile.mkdtemp(prefix="nrf_dfu_bl_sett")
            temp_sd_file = os.path.join(os.getcwd(), 'temp_sd_file.hex')

            # Load SD hex file and remove MBR before calculating keys
            ih_sd = intelhex.IntelHex(sd_file)
            ih_sd_no_mbr = intelhex.IntelHex()
            ih_sd_no_mbr.merge(ih_sd[0x1000:], overlap='error')
            ih_sd_no_mbr.write_hex_file(temp_sd_file)

            self.sd_bin = Package.normalize_firmware_to_bin(self.temp_dir, temp_sd_file)
            os.remove(temp_sd_file)

            self.sd_sz = int(Package.calculate_file_size(self.sd_bin)) & 0xffffffff

            # Calculate Boot validation fields for SD
            if sd_boot_validation_type == 'VALIDATE_GENERATED_CRC':
                self.sd_boot_validation_type = 1 & 0xffffffff
                sd_crc = int(Package.calculate_crc(32, self.sd_bin)) & 0xffffffff
                self.sd_boot_validation_bytes = struct.pack('<I', sd_crc)
            elif sd_boot_validation_type == 'VALIDATE_GENERATED_SHA256':
                self.sd_boot_validation_type = 2 & 0xffffffff
                # Package.calculate_sha256_hash gives a reversed
                # digest. It need to be reversed back to a normal
                # sha256 digest.
                self.sd_boot_validation_bytes = Package.calculate_sha256_hash(self.sd_bin)[::-1]
            elif sd_boot_validation_type == 'VALIDATE_ECDSA_P256_SHA256':
                self.sd_boot_validation_type = 3 & 0xffffffff
                self.sd_boot_validation_bytes = Package.sign_firmware(signer, self.sd_bin)
            else:  # This also covers 'NO_VALIDATION_CASE'
                self.sd_boot_validation_type = 0 & 0xffffffff
                self.sd_boot_validation_bytes = bytes(0)
        else:
            self.sd_sz = 0x0 & 0xffffffff
            self.sd_boot_validation_type = 0 & 0xffffffff
            self.sd_boot_validation_bytes = bytes(0)

        # additional hardcoded values
        self.bank_layout = 0x0 & 0xffffffff
        self.bank_current = 0x0 & 0xffffffff

        # Fill the entire settings page with 0's
        for offset in range(0, self.setts.bytes_count):
            self.ihex[self.bl_sett_addr + offset] = 0x00
            
        # Make sure the hex-file is 32bit-word-aligned
        fill_bytes = ((self.setts.bytes_count + 4 - 1) & ~(4 - 1)) - self.setts.bytes_count
        for offset in range(self.setts.bytes_count, self.setts.bytes_count + fill_bytes):
            self.ihex[self.bl_sett_addr + offset] = 0xFF
        
        self._add_value_tohex(self.setts.sett_ver, self.bl_sett_ver)
        self._add_value_tohex(self.setts.app_ver, self.app_ver)
        self._add_value_tohex(self.setts.bl_ver, self.bl_ver)
        self._add_value_tohex(self.setts.bank_layout, self.bank_layout)
        self._add_value_tohex(self.setts.bank_current, self.bank_current)
        self._add_value_tohex(self.setts.bank0_img_sz, self.app_sz)
        self._add_value_tohex(self.setts.bank0_img_crc, self.app_crc)
        self._add_value_tohex(self.setts.bank0_bank_code, self.bank0_bank_code)
        self._add_value_tohex(self.setts.sd_sz, self.sd_sz)

        self.boot_validation_crc = 0x0 & 0xffffffff
        if self.bl_sett_ver == 2:
            self._add_value_tohex(self.setts.sd_validation_type, self.sd_boot_validation_type, '<b')
            self.ihex.puts(self.setts.sd_validation_bytes, self.sd_boot_validation_bytes)

            self._add_value_tohex(self.setts.app_validation_type, self.app_boot_validation_type, '<b')
            self.ihex.puts(self.setts.app_validation_bytes, self.app_boot_validation_bytes)

            self.boot_validation_crc = self._calculate_crc32_from_hex(self.ihex,
                                                                      start_addr=self.setts.sd_validation_type,
                                                                      end_addr=self.setts.last_addr) & 0xffffffff
            self._add_value_tohex(self.setts.boot_validataion_crc, self.boot_validation_crc)

        self.crc = self._calculate_crc32_from_hex(self.ihex,
                                                  start_addr=self.bl_sett_addr+4,
                                                  end_addr=self.setts.init_cmd - 1) & 0xffffffff
        self._add_value_tohex(self.setts.crc, self.crc)

        if backup_address is None:
            self.backup_address = self.bl_sett_addr - self.bl_sett_backup_offset
        else:
            self.backup_address = backup_address

        if not no_backup:
            for offset in range(0, self.setts.bytes_count):
                self.ihex[self.backup_address + offset] = self.ihex[self.bl_sett_addr + offset]
            for offset in range(self.setts.bytes_count, self.setts.bytes_count + fill_bytes):
                self.ihex[self.backup_address + offset] = 0xFF

    def probe_settings(self, base):
        # Unpack CRC and version
        fmt = '<I'
        crc = struct.unpack(fmt, self.ihex.gets(base + 0, 4))[0] & 0xffffffff
        ver = struct.unpack(fmt, self.ihex.gets(base + 4, 4))[0] & 0xffffffff

        if ver == 1:
            self.setts = BLDFUSettingsStructV1(base)
        elif ver == 2:
            self.setts = BLDFUSettingsStructV2(base)
        else:
            raise RuntimeError("Unknown Bootloader DFU settings version: {0}".format(ver))

        # calculate the CRC32 over the data
        _crc = self._calculate_crc32_from_hex(self.ihex,
                                              start_addr=base + 4,
                                              end_addr=self.setts.init_cmd - 1) & 0xffffffff

        if _crc != crc:
            raise RuntimeError("CRC32 mismtach: flash: {0} calculated: {1}".format(hex(crc), hex(_crc)))

        self.crc = crc
        self.bl_sett_ver     = self._get_value_fromhex(self.setts.sett_ver)
        self.app_ver         = self._get_value_fromhex(self.setts.app_ver)
        self.bl_ver          = self._get_value_fromhex(self.setts.bl_ver)
        self.bank_layout     = self._get_value_fromhex(self.setts.bank_layout)
        self.bank_current    = self._get_value_fromhex(self.setts.bank_current)
        self.app_sz          = self._get_value_fromhex(self.setts.bank0_img_sz)
        self.app_crc         = self._get_value_fromhex(self.setts.bank0_img_crc)
        self.bank0_bank_code = self._get_value_fromhex(self.setts.bank0_bank_code)

        if self.bl_sett_ver == 2:
            self.sd_sz                    = self._get_value_fromhex(self.setts.sd_sz)
            self.boot_validation_crc      = self._get_value_fromhex(self.setts.boot_validataion_crc)
            self.sd_boot_validation_type  = self._get_value_fromhex(self.setts.sd_validation_type, size=1, format='<b')
            self.app_boot_validation_type = self._get_value_fromhex(self.setts.app_validation_type, size=1, format='<b')
        else:
            self.sd_sz                    = 0x0 & 0xffffffff
            self.boot_validation_crc      = 0x0 & 0xffffffff
            self.sd_boot_validation_type  = 0x0 & 0xffffffff
            self.app_boot_validation_type = 0x0 & 0xffffffff

    def fromhexfile(self, f, arch=None):
        self.hex_file = f
        self.ihex.fromfile(f, format='hex')

        # check the 3 possible addresses for CRC matches
        try:
            self.probe_settings(BLDFUSettings.bl_sett_51_addr)
            self.set_arch('NRF51')
        except Exception as e:
            try:
                self.probe_settings(BLDFUSettings.bl_sett_52_addr)
                self.set_arch('NRF52')
            except Exception as e:
                print(e)
                try:
                    self.probe_settings(BLDFUSettings.bl_sett_52_qfab_addr)
                    self.set_arch('NRF52QFAB')
                except Exception as e:
                    try:
                        self.probe_settings(BLDFUSettings.bl_sett_52810_addr)
                        self.set_arch('NRF52810')
                    except Exception as e:
                        try:
                            self.probe_settings(BLDFUSettings.bl_sett_52840_addr)
                            self.set_arch('NRF52840')
                        except Exception as e:
                            raise NordicSemiException("Failed to parse .hex file: {0}".format(e))

        self.bl_sett_addr = self.ihex.minaddr()

    def __str__(self):
        s = """
Bootloader DFU Settings:
* File:                     {0}
* Family:                   {1}
* Start Address:            0x{2:08X}
* CRC:                      0x{3:08X}
* Settings Version:         0x{4:08X} ({4})
* App Version:              0x{5:08X} ({5})
* Bootloader Version:       0x{6:08X} ({6})
* Bank Layout:              0x{7:08X}
* Current Bank:             0x{8:08X}
* Application Size:         0x{9:08X} ({9} bytes)
* Application CRC:          0x{10:08X}
* Bank0 Bank Code:          0x{11:08X}
* Softdevice Size:          0x{12:08X} ({12} bytes)
* Boot Validation CRC:      0x{13:08X}
* SD Boot Validation Type:  0x{14:08X} ({14})
* App Boot Validation Type: 0x{15:08X} ({15})
""".format(self.hex_file, self.arch_str, self.bl_sett_addr, self.crc, self.bl_sett_ver, self.app_ver,
           self.bl_ver, self.bank_layout, self.bank_current, self.app_sz, self.app_crc, self.bank0_bank_code,
           self.sd_sz, self.boot_validation_crc, self.sd_boot_validation_type, self.app_boot_validation_type)
        return s

    def tohexfile(self, f):
        self.hex_file = f
        self.ihex.tofile(f, format='hex')



#!/usr/bin/env python
#
# Copyright (c) 2016 Nordic Semiconductor ASA
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#   1. Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
#
#   2. Redistributions in binary form must reproduce the above copyright notice, this
#   list of conditions and the following disclaimer in the documentation and/or
#   other materials provided with the distribution.
#
#   3. Neither the name of Nordic Semiconductor ASA nor the names of other
#   contributors to this software may be used to endorse or promote products
#   derived from this software without specific prior written permission.
#
#   4. This software must only be used in or with a processor manufactured by Nordic
#   Semiconductor ASA, or in or with a processor manufactured by a third party that
#   is used in combination with a processor manufactured by Nordic Semiconductor.
#
#   5. Any software provided in binary or object form under this license must not be
#   reverse engineered, decompiled, modified and/or disassembled.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
# ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
"""
Setup script for nrfutil.

USAGE:
    python setup.py install

"""
import os
import sys

from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand

from nordicsemi import version

# Change directory to be able to run python setup.py develop from another directory
os.chdir(os.path.dirname(os.path.realpath(__file__)))

install_package = True
try:
    #  If the version that is being installed is older than the one currently installed, suggest
    #  to use a virtual environment.

    import pkg_resources
    installed_packages = [d for d in pkg_resources.working_set]
    flat_installed_packages = [package.project_name for package in installed_packages]
    package = installed_packages[flat_installed_packages.index('nrfutil')]
    installed_versions = [int(i) for i in package.version.split(".")]
    new_versions = [int(i) for i in version.NRFUTIL_VERSION.split(".")]
    legacy_version = False
    for v1, v2 in zip(installed_versions, new_versions):
        if v1 == v2:
            continue
        if v2 < v1:
            legacy_version = True
        break

    if legacy_version:
        valid_response = ["y", "yes"]
        msg = ("A newer version of nrfutil may already be installed. Consider using a separate "
               "virtual environment when installing legacy versions. \nProceed (y/N)? ")
        print(msg)
        sys.stdout.flush()
        prompt = sys.stdin.readline().strip()
        if(prompt.lower() not in valid_response):
            install_package = False

except ImportError:
    pass  # pkg_resources not available.
except Exception:
    pass  # Nrfutil is not already installed.


# Exit program if user doesn't want to replace newer version.
if(not install_package):
    sys.exit(1)


excludes = ["Tkconstants",
            "Tkinter",
            "tcl",
            "pickle",
            "unittest",
            "pyreadline"]

# DFU component cli interface
includes = ["nordicsemi.dfu.dfu"]

packages = []

dll_excludes = [
    "w9xpopen.exe",
    "OLEAUT32.DLL",
    "OLE32.DLL",
    "USER32.DLL",
    "SHELL32.DLL",
    "ADVAPI32.DLL",
    "KERNEL32.DLL",
    "WS2_32.DLL",
    "GDI32.DLL"]

build_dir = os.environ.get("NRFUTIL_BUILD_DIR", "./{}".format(version.NRFUTIL_VERSION))
description = """A Python package that includes the nrfutil utility and the nordicsemi library"""

with open("requirements.txt") as reqs_file:
    reqs = reqs_file.readlines()


class NoseTestCommand(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import nose
        nose.run_exit(argv=['nosetests', '--with-xunit', '--xunit-file=unittests.xml'])


setup(
    name="nrfutil",
    version=version.NRFUTIL_VERSION,
    license="Other/Proprietary License",
    author="Nordic Semiconductor ASA",
    url="https://github.com/NordicSemiconductor/pc-nrfutil",
    description="Nordic Semiconductor nrfutil utility and Python library",
    long_description=description,
    packages=find_packages(exclude=["tests.*", "tests"]),
    package_data={
                '': ['../requirements.txt', 'thread/hex/ncp.hex', 'zigbee/hex/ota.hex',
                     '../libusb/x86/libusb-1.0.dll', '../libusb/x64/libusb-1.0.dll',
                     '../libusb/x64/libusb-1.0.dylib', '../libusb/LICENSE']
    },
    python_requires='>=3.7, <3.11',
    install_requires=reqs,
    zipfile=None,
    tests_require=[
        "nose >= 1.3.4",
        "behave"
    ],
    zip_safe=False,
    classifiers=[
        'Development Status :: 4 - Beta',

        'Intended Audience :: Developers',

        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX :: Linux',

        'Topic :: System :: Networking',
        'Topic :: System :: Hardware :: Hardware Drivers',
        'Topic :: Software Development :: Embedded Systems',

        'License :: Other/Proprietary License',

        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    keywords='nordic nrf51 nrf52 ble bluetooth dfu ota softdevice serialization nrfutil pc-nrfutil',
    cmdclass={
        'test': NoseTestCommand
    },
    entry_points='''
      [console_scripts]
      nrfutil = nordicsemi.__main__:cli
    ''',
    console=[{
        "script": "./nordicsemi/__main__.py",
        "dest_base": "nrfutil"
    }],
)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nordicsemi/dfu/dfu-cc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='nordicsemi/dfu/dfu-cc.proto',
  package='dfu',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1bnordicsemi/dfu/dfu-cc.proto\x12\x03\x64\x66u\"6\n\x04Hash\x12 \n\thash_type\x18\x01 \x02(\x0e\x32\r.dfu.HashType\x12\x0c\n\x04hash\x18\x02 \x02(\x0c\"B\n\x0e\x42ootValidation\x12!\n\x04type\x18\x01 \x02(\x0e\x32\x13.dfu.ValidationType\x12\r\n\x05\x62ytes\x18\x02 \x02(\x0c\"\xf8\x01\n\x0bInitCommand\x12\x12\n\nfw_version\x18\x01 \x01(\r\x12\x12\n\nhw_version\x18\x02 \x01(\r\x12\x12\n\x06sd_req\x18\x03 \x03(\rB\x02\x10\x01\x12\x19\n\x04type\x18\x04 \x01(\x0e\x32\x0b.dfu.FwType\x12\x0f\n\x07sd_size\x18\x05 \x01(\r\x12\x0f\n\x07\x62l_size\x18\x06 \x01(\r\x12\x10\n\x08\x61pp_size\x18\x07 \x01(\r\x12\x17\n\x04hash\x18\x08 \x01(\x0b\x32\t.dfu.Hash\x12\x17\n\x08is_debug\x18\t \x01(\x08:\x05\x66\x61lse\x12,\n\x0f\x62oot_validation\x18\n \x03(\x0b\x32\x13.dfu.BootValidation\"\x1f\n\x0cResetCommand\x12\x0f\n\x07timeout\x18\x01 \x02(\r\"i\n\x07\x43ommand\x12\x1c\n\x07op_code\x18\x01 \x01(\x0e\x32\x0b.dfu.OpCode\x12\x1e\n\x04init\x18\x02 \x01(\x0b\x32\x10.dfu.InitCommand\x12 \n\x05reset\x18\x03 \x01(\x0b\x32\x11.dfu.ResetCommand\"m\n\rSignedCommand\x12\x1d\n\x07\x63ommand\x18\x01 \x02(\x0b\x32\x0c.dfu.Command\x12*\n\x0esignature_type\x18\x02 \x02(\x0e\x32\x12.dfu.SignatureType\x12\x11\n\tsignature\x18\x03 \x02(\x0c\"S\n\x06Packet\x12\x1d\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x0c.dfu.Command\x12*\n\x0esigned_command\x18\x02 \x01(\x0b\x32\x12.dfu.SignedCommand*\x1d\n\x06OpCode\x12\t\n\x05RESET\x10\x00\x12\x08\n\x04INIT\x10\x01*n\n\x06\x46wType\x12\x0f\n\x0b\x41PPLICATION\x10\x00\x12\x0e\n\nSOFTDEVICE\x10\x01\x12\x0e\n\nBOOTLOADER\x10\x02\x12\x19\n\x15SOFTDEVICE_BOOTLOADER\x10\x03\x12\x18\n\x14\x45XTERNAL_APPLICATION\x10\x04*D\n\x08HashType\x12\x0b\n\x07NO_HASH\x10\x00\x12\x07\n\x03\x43RC\x10\x01\x12\n\n\x06SHA128\x10\x02\x12\n\n\x06SHA256\x10\x03\x12\n\n\x06SHA512\x10\x04*t\n\x0eValidationType\x12\x11\n\rNO_VALIDATION\x10\x00\x12\x1a\n\x16VALIDATE_GENERATED_CRC\x10\x01\x12\x13\n\x0fVALIDATE_SHA256\x10\x02\x12\x1e\n\x1aVALIDATE_ECDSA_P256_SHA256\x10\x03*3\n\rSignatureType\x12\x15\n\x11\x45\x43\x44SA_P256_SHA256\x10\x00\x12\x0b\n\x07\x45\x44\x32\x35\x35\x31\x39\x10\x01')
)

_OPCODE = _descriptor.EnumDescriptor(
  name='OpCode',
  full_name='dfu.OpCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INIT', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=747,
  serialized_end=776,
)
_sym_db.RegisterEnumDescriptor(_OPCODE)

OpCode = enum_type_wrapper.EnumTypeWrapper(_OPCODE)
_FWTYPE = _descriptor.EnumDescriptor(
  name='FwType',
  full_name='dfu.FwType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='APPLICATION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFTDEVICE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOTLOADER', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFTDEVICE_BOOTLOADER', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL_APPLICATION', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=778,
  serialized_end=888,
)
_sym_db.RegisterEnumDescriptor(_FWTYPE)

FwType = enum_type_wrapper.EnumTypeWrapper(_FWTYPE)
_HASHTYPE = _descriptor.EnumDescriptor(
  name='HashType',
  full_name='dfu.HashType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_HASH', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA128', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA256', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHA512', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=890,
  serialized_end=958,
)
_sym_db.RegisterEnumDescriptor(_HASHTYPE)

HashType = enum_type_wrapper.EnumTypeWrapper(_HASHTYPE)
_VALIDATIONTYPE = _descriptor.EnumDescriptor(
  name='ValidationType',
  full_name='dfu.ValidationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_VALIDATION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALIDATE_GENERATED_CRC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALIDATE_SHA256', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALIDATE_ECDSA_P256_SHA256', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=960,
  serialized_end=1076,
)
_sym_db.RegisterEnumDescriptor(_VALIDATIONTYPE)

ValidationType = enum_type_wrapper.EnumTypeWrapper(_VALIDATIONTYPE)
_SIGNATURETYPE = _descriptor.EnumDescriptor(
  name='SignatureType',
  full_name='dfu.SignatureType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ECDSA_P256_SHA256', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ED25519', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1078,
  serialized_end=1129,
)
_sym_db.RegisterEnumDescriptor(_SIGNATURETYPE)

SignatureType = enum_type_wrapper.EnumTypeWrapper(_SIGNATURETYPE)
RESET = 0
INIT = 1
APPLICATION = 0
SOFTDEVICE = 1
BOOTLOADER = 2
SOFTDEVICE_BOOTLOADER = 3
EXTERNAL_APPLICATION = 4
NO_HASH = 0
CRC = 1
SHA128 = 2
SHA256 = 3
SHA512 = 4
NO_VALIDATION = 0
VALIDATE_GENERATED_CRC = 1
VALIDATE_SHA256 = 2
VALIDATE_ECDSA_P256_SHA256 = 3
ECDSA_P256_SHA256 = 0
ED25519 = 1



_HASH = _descriptor.Descriptor(
  name='Hash',
  full_name='dfu.Hash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash_type', full_name='dfu.Hash.hash_type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='dfu.Hash.hash', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=90,
)


_BOOTVALIDATION = _descriptor.Descriptor(
  name='BootValidation',
  full_name='dfu.BootValidation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dfu.BootValidation.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes', full_name='dfu.BootValidation.bytes', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=158,
)


_INITCOMMAND = _descriptor.Descriptor(
  name='InitCommand',
  full_name='dfu.InitCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fw_version', full_name='dfu.InitCommand.fw_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hw_version', full_name='dfu.InitCommand.hw_version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sd_req', full_name='dfu.InitCommand.sd_req', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='dfu.InitCommand.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sd_size', full_name='dfu.InitCommand.sd_size', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bl_size', full_name='dfu.InitCommand.bl_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_size', full_name='dfu.InitCommand.app_size', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='dfu.InitCommand.hash', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_debug', full_name='dfu.InitCommand.is_debug', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boot_validation', full_name='dfu.InitCommand.boot_validation', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=409,
)


_RESETCOMMAND = _descriptor.Descriptor(
  name='ResetCommand',
  full_name='dfu.ResetCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='dfu.ResetCommand.timeout', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=442,
)


_COMMAND = _descriptor.Descriptor(
  name='Command',
  full_name='dfu.Command',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op_code', full_name='dfu.Command.op_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='init', full_name='dfu.Command.init', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reset', full_name='dfu.Command.reset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=549,
)


_SIGNEDCOMMAND = _descriptor.Descriptor(
  name='SignedCommand',
  full_name='dfu.SignedCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='dfu.SignedCommand.command', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature_type', full_name='dfu.SignedCommand.signature_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='dfu.SignedCommand.signature', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=660,
)


_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='dfu.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='dfu.Packet.command', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signed_command', full_name='dfu.Packet.signed_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=745,
)

_HASH.fields_by_name['hash_type'].enum_type = _HASHTYPE
_BOOTVALIDATION.fields_by_name['type'].enum_type = _VALIDATIONTYPE
_INITCOMMAND.fields_by_name['type'].enum_type = _FWTYPE
_INITCOMMAND.fields_by_name['hash'].message_type = _HASH
_INITCOMMAND.fields_by_name['boot_validation'].message_type = _BOOTVALIDATION
_COMMAND.fields_by_name['op_code'].enum_type = _OPCODE
_COMMAND.fields_by_name['init'].message_type = _INITCOMMAND
_COMMAND.fields_by_name['reset'].message_type = _RESETCOMMAND
_SIGNEDCOMMAND.fields_by_name['command'].message_type = _COMMAND
_SIGNEDCOMMAND.fields_by_name['signature_type'].enum_type = _SIGNATURETYPE
_PACKET.fields_by_name['command'].message_type = _COMMAND
_PACKET.fields_by_name['signed_command'].message_type = _SIGNEDCOMMAND
DESCRIPTOR.message_types_by_name['Hash'] = _HASH
DESCRIPTOR.message_types_by_name['BootValidation'] = _BOOTVALIDATION
DESCRIPTOR.message_types_by_name['InitCommand'] = _INITCOMMAND
DESCRIPTOR.message_types_by_name['ResetCommand'] = _RESETCOMMAND
DESCRIPTOR.message_types_by_name['Command'] = _COMMAND
DESCRIPTOR.message_types_by_name['SignedCommand'] = _SIGNEDCOMMAND
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
DESCRIPTOR.enum_types_by_name['OpCode'] = _OPCODE
DESCRIPTOR.enum_types_by_name['FwType'] = _FWTYPE
DESCRIPTOR.enum_types_by_name['HashType'] = _HASHTYPE
DESCRIPTOR.enum_types_by_name['ValidationType'] = _VALIDATIONTYPE
DESCRIPTOR.enum_types_by_name['SignatureType'] = _SIGNATURETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Hash = _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), dict(
  DESCRIPTOR = _HASH,
  __module__ = 'nordicsemi.dfu.dfu_cc_pb2'
  # @@protoc_insertion_point(class_scope:dfu.Hash)
  ))
_sym_db.RegisterMessage(Hash)

BootValidation = _reflection.GeneratedProtocolMessageType('BootValidation', (_message.Message,), dict(
  DESCRIPTOR = _BOOTVALIDATION,
  __module__ = 'nordicsemi.dfu.dfu_cc_pb2'
  # @@protoc_insertion_point(class_scope:dfu.BootValidation)
  ))
_sym_db.RegisterMessage(BootValidation)

InitCommand = _reflection.GeneratedProtocolMessageType('InitCommand', (_message.Message,), dict(
  DESCRIPTOR = _INITCOMMAND,
  __module__ = 'nordicsemi.dfu.dfu_cc_pb2'
  # @@protoc_insertion_point(class_scope:dfu.InitCommand)
  ))
_sym_db.RegisterMessage(InitCommand)

ResetCommand = _reflection.GeneratedProtocolMessageType('ResetCommand', (_message.Message,), dict(
  DESCRIPTOR = _RESETCOMMAND,
  __module__ = 'nordicsemi.dfu.dfu_cc_pb2'
  # @@protoc_insertion_point(class_scope:dfu.ResetCommand)
  ))
_sym_db.RegisterMessage(ResetCommand)

Command = _reflection.GeneratedProtocolMessageType('Command', (_message.Message,), dict(
  DESCRIPTOR = _COMMAND,
  __module__ = 'nordicsemi.dfu.dfu_cc_pb2'
  # @@protoc_insertion_point(class_scope:dfu.Command)
  ))
_sym_db.RegisterMessage(Command)

SignedCommand = _reflection.GeneratedProtocolMessageType('SignedCommand', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDCOMMAND,
  __module__ = 'nordicsemi.dfu.dfu_cc_pb2'
  # @@protoc_insertion_point(class_scope:dfu.SignedCommand)
  ))
_sym_db.RegisterMessage(SignedCommand)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), dict(
  DESCRIPTOR = _PACKET,
  __module__ = 'nordicsemi.dfu.dfu_cc_pb2'
  # @@protoc_insertion_point(class_scope:dfu.Packet)
  ))
_sym_db.RegisterMessage(Packet)


_INITCOMMAND.fields_by_name['sd_req']._options = None
# @@protoc_insertion_point(module_scope)
